.. _generators:

****************************************
Generators (`baseband_tasks.generators`)
****************************************

`~baseband_tasks.generators` contains helpers to generate streams of
data.

.. _generators_api:

Reference/API
=============

.. automodapi:: baseband_tasks.generators
   :no-inherited-members:
